function  S_plot_Cl_LJ_clb1(ncl,xcl,ycl,zcl,nv1,nv2)
% This subroutine draws the geometry of 
% a minimal Lennard Jones Potential cluster
% The input parameters are:
% ncl : numbers of particles
% xcl, ycl, zcl: arrays of numbers corresponding to the 3D
% cluster's coordinates
% nv1, nv2 : integer number to determine the shells to draw
% With nv1=0 and nv2=2, the cluster's nucleo and the first shell
% are depicted
% ====================================================================
% More information of this subroutine is in the article:
% Discrete Optimal Global Congergence of a Novel Evolutionary Algorith
% for Clusters under Lennard JOnes Potential
% Author: Carlos Barron Romero
% Universidad Autonoma Metropolitana, campus Azcapotzalco
% Mexico City.
% This subroutine can be freely used, distributed or modified under 
% your own responsability.
% ====================================================================
%
% Compute center of mass 
xclm=mean(xcl);
yclm=mean(ycl);
zclm=mean(zcl);
% Arrays for particle's neighboors and number of neighboors
vec=zeros(ncl,12);
nvc=zeros(ncl,1);
% dmg is the optimal distance of a pair of particles under 
% Lennard Jones Potential
dmg=1.0; % Normalizado
% 10% is the factor to define the lower and upper limits
% for acepting a particle's neighboor
tol=0.2;
d_inf = dmg * (1 - tol);
d_sup = dmg * (1 + tol);
%
% This loop determines the particle's neighboor
for i=1:ncl-1
    for j=i+1:ncl
        dij=norm([(xcl(i)-xcl(j)),(ycl(i)-ycl(j)),(zcl(i)-zcl(j))]);
        if ((d_inf < dij) && (dij < d_sup))
            nvc(i)=nvc(i)+1;
            vec(i,nvc(i))=j;
            nvc(j)=nvc(j)+1;
            vec(j,nvc(j))=i;
        end
    end
end
% dmg*03 is a ratio ratio from the cluster's center of mass
% for selecting a particle as a nucleo 
ra = dmg*0.3;
pnuc=zeros(13,1);
nnuc=0;
fnuc = 0;
for i=1:ncl
    dcl=norm([(xcl(i)-xclm),(ycl(i)-yclm),(zcl(i)-zclm)]);
    if (dcl < ra)
        nnuc=nnuc+1;
        pnuc(nnuc)=i;
    end
end
% Such particle must be unique and close to the cluster's 
% center of mass (xclm,yclm,zclm)
if (nnuc == 1)
    fnuc=1;
end
% Otherwise, try to determine if two particles are
% closed to the cluster's center of mass
if  (fnuc == 0)
    nnuc=0;
    %  dmg * 0.6 is the ratio from the cluster's center of mass
    % to look for two patricles
    ra = dmg * 0.6;
    for i=1:ncl
        dcl=norm([(xcl(i)-xclm),(ycl(i)-yclm),(zcl(i)-zclm)]);
        if (dcl < ra)
            nnuc=nnuc+1;
            pnuc(nnuc)=i;
        end
    end
    % With two particles, their line center is used
    % to look for a nucleo (pentagonal polyhedron bipyramide, n7)
    if (nnuc == 2)
        xctr=0.0;
        yctr=0.0;
        zctr=0.0;
        % calcula el centro de los cercanos al centro de masa
        for i=1:nnuc
            i1 = pnuc(i);
            xctr= xctr + xcl(i1);
            yctr= yctr + ycl(i1);
            zctr= zctr + zcl(i1);
        end
        xctr= xctr / nnuc;
        yctr= yctr / nnuc;
        zctr= zctr / nnuc;
        ra_7 = dmg*0.99;
        pnuc_7=zeros(13,1);
        nnuc_7=0;
        for i=1:ncl
            dcl=norm([(xcl(i)-xctr),(ycl(i)-yctr),(zcl(i)-zctr)]);
            if (dcl < ra_7)
                nnuc_7=nnuc_7+1;
                pnuc_7(nnuc_7)=i;
            end
        end
        if nnuc_7 == 7
            % This cluster has a pentagonal polyhedron bipyramide, n7
            nnuc=nnuc_7;
            pnuc=pnuc_7;
            ra = ra_7;
            fnuc = 1;
        end
    end
end
% Otherwise, try to determine if the cluster has a nucleo of 
% four (tetrahedron, n4), five (Trigonal bipyramid, n5), or
% six particles (octahedron, n6)
if  (fnuc == 0)
    nnuc=0;
    ra = dmg * 0.8;
    for i=1:ncl
        dcl=norm([(xcl(i)-xclm),(ycl(i)-yclm),(zcl(i)-zclm)]);
        if (dcl < ra)
            nnuc=nnuc+1;
            pnuc(nnuc)=i;
        end
    end
    if ((nnuc == 4) || (nnuc == 5) || (nnuc == 6))
%       This cluster has a nucleo n4 or n5 or n6
        fnuc=1;
    end
end
% Otherwise, try to determine if the cluster has a biased
% from the cluster's center of mass for five (Trigonal bipyramid, n5), or
% six particles (octahedron, n6)
if (fnuc == 0)
    ra = dmg*0.79;
    nnuc=0;
    for i=1:ncl
        dcl=norm([(xcl(i)-xclm),(ycl(i)-yclm),(zcl(i)-zclm)]);
        if (dcl < ra)
            nnuc=nnuc+1;
            pnuc(nnuc)=i;
        end
    end
    if nnuc > 0
        xctr=0.0;
        yctr=0.0;
        zctr=0.0;
        % In this case, it estimates the center of 
        % mass of the closed particles around dmg * 0.79
        % of the cluster's center of mass
        for i=1:nnuc
            i1 = pnuc(i);
            xctr= xctr + xcl(i1);
            yctr= yctr + ycl(i1);
            zctr= zctr + zcl(i1);
        end
        xctr= xctr / nnuc;
        yctr= yctr / nnuc;
        zctr= zctr / nnuc;
        ra_7 = dmg*0.97;
        pnuc_7=zeros(13,1);
        nnuc_7=0;
        for i=1:ncl
            dcl=norm([(xcl(i)-xctr),(ycl(i)-yctr),(zcl(i)-zctr)]);
            if (dcl < ra_7)
                nnuc_7=nnuc_7+1;
                pnuc_7(nnuc_7)=i;
            end
        end
        if (nnuc_7 == 5) || (nnuc_7 == 6)
%       This cluster has a nucleo n5 or n6
            nnuc=nnuc_7;
            pnuc=pnuc_7;
            ra = ra_7;
            xclm = xctr;
            yclm = yctr;
            zclm = zctr;
            fnuc = 1;
        end
    end
end
% Otherwise, try to determine if the cluster has a nucleo of
% twelve particles
if (fnuc == 0)
    % dmg * 1.15 is the ratio from the cluster's center of mass to
    % determine a nucleo of 12 particles
    ra = dmg* 1.15;
    nnuc=0;
    for i=1:ncl
        dcl=norm([(xcl(i)-xclm),(ycl(i)-yclm),(zcl(i)-zclm)]);
        if (dcl < ra)
            nnuc=nnuc+1;
            pnuc(nnuc)=i;
        end
    end
    if (nnuc == 12)
        fnuc=1;
    end
end
% Otherwise 
if fnuc == 0
    linp=sprintf('The cluster of %4.4d has no classification n1, n4, n5, n6, n12',ncl);
    disp(linp);
    return;
end
% With a nucleo, is is possible to determine the cluster's shells
capa=zeros(ncl,1);
ncapa=1;
Queue(ncl);
for jp=1:nnuc
    capa(pnuc(jp))=1;
    Enqueue(pnuc(jp));
end
while (~(IsEmptyqueue))
    ui = Headqueue;
    for jv=1:nvc(ui)
        pvc=vec(ui,jv);
        if (capa(pvc)== 0)
            capa(pvc) = capa(ui) + 1;
            Enqueue(pvc);
        end
    end
    Dequeue;
end
% Color table
tclr = [ 1,0,0; ...
    0,1,0; ...
    0,0,1; ...
    1,1,0; ... 
    51/255, 153/255, 1; ...
    1,0,1; ... 
    0.5,0.5,1; ... 
    0.5,0.5,0.5; ...
    1,0.5,1; ...
    1,0.5,0.5; ...
    1,0.5,0.75; ...
    1,0.75,0; ...
    0,0,0];
hold on;
for i=1:ncl
    if (capa(i) < nv1)
        continue;
    end
    if (capa(i) > nv2)
        continue;
    end
    % cluster's lines
    for jv=1:nvc(i)
        pvc=vec(i,jv);
        if (capa(i) == capa (pvc))
            line([xcl(i),xcl(pvc)], ...
                [ycl(i),ycl(pvc)], ...
                [zcl(i),zcl(pvc)], ...
                'Color',tclr(capa(i),:), ...
                'LineWidth',1);

        end
    end
    % particles
    plot3(xcl(i), ...
        ycl(i), ...
        zcl(i), '-ko',...
        'LineWidth',1,...
        'MarkerEdgeColor','k', ...
        'MarkerFaceColor',tclr(capa(i),:),...
        'MarkerSize',8);
end
axis equal;
grid on;
linp=sprintf('Cluster of %d particles',ncl);
title(linp);
view(45,45);
hold off;
